module Kramdown

  module Utils

    # Provides convenience methods for handling named and numeric entities.
    module Entities

      # Represents an entity that has a +code_point+ and +name+.
      class Entity

        # Return the UTF8 representation of the entity.
        def char
          if code_point.instance_of?(Array)
            [*code_point].pack('U*') rescue nil
          else
            [code_point].pack('U*') rescue nil
          end
        end
      end

      EXTEND_ENTITY_TABLE = [
        [9, "Tab"],
        [10, "NewLine"],
        [33, "excl"],
        [34, "QUOT"],
        [35, "num"],
        [36, "dollar"],
        [37, "percnt"],
        [38, "AMP"],
        [40, "lpar"],
        [41, "rpar"],
        [42, "ast"],
        [42, "midast"],
        [43, "plus"],
        [44, "comma"],
        [46, "period"],
        [47, "sol"],
        [58, "colon"],
        [59, "semi"],
        [60, "LT"],
        [[60, 8402], "nvlt"],
        [61, "equals"],
        [[61, 8421], "bne"],
        [62, "GT"],
        [[62, 8402], "nvgt"],
        [63, "quest"],
        [64, "commat"],
        [91, "lbrack"],
        [91, "lsqb"],
        [92, "bsol"],
        [93, "rsqb"],
        [93, "rbrack"],
        [94, "Hat"],
        [95, "lowbar"],
        [95, "UnderBar"],
        [96, "DiacriticalGrave"],
        [96, "grave"],
        [[102, 106], "fjlig"],
        [123, "lbrace"],
        [123, "lcub"],
        [124, "vert"],
        [124, "VerticalLine"],
        [124, "verbar"],
        [125, "rcub"],
        [125, "rbrace"],
        [160, "NonBreakingSpace"],
        [168, "DoubleDot"],
        [168, "die"],
        [168, "Dot"],
        [169, "COPY"],
        [174, "circledR"],
        [174, "REG"],
        [175, "strns"],
        [177, "pm"],
        [177, "PlusMinus"],
        [180, "DiacriticalAcute"],
        [183, "centerdot"],
        [183, "CenterDot"],
        [184, "Cedilla"],
        [189, "half"],
        [197, "angst"],
        [247, "div"],
        [256, "Amacr"],
        [257, "amacr"],
        [258, "Abreve"],
        [259, "abreve"],
        [260, "Aogon"],
        [261, "aogon"],
        [262, "Cacute"],
        [263, "cacute"],
        [264, "Ccirc"],
        [265, "ccirc"],
        [266, "Cdot"],
        [267, "cdot"],
        [268, "Ccaron"],
        [269, "ccaron"],
        [270, "Dcaron"],
        [271, "dcaron"],
        [272, "Dstrok"],
        [273, "dstrok"],
        [274, "Emacr"],
        [275, "emacr"],
        [278, "Edot"],
        [279, "edot"],
        [280, "Eogon"],
        [281, "eogon"],
        [282, "Ecaron"],
        [283, "ecaron"],
        [284, "Gcirc"],
        [285, "gcirc"],
        [286, "Gbreve"],
        [287, "gbreve"],
        [288, "Gdot"],
        [289, "gdot"],
        [290, "Gcedil"],
        [292, "Hcirc"],
        [293, "hcirc"],
        [294, "Hstrok"],
        [295, "hstrok"],
        [296, "Itilde"],
        [297, "itilde"],
        [298, "Imacr"],
        [299, "imacr"],
        [302, "Iogon"],
        [303, "iogon"],
        [304, "Idot"],
        [305, "inodot"],
        [305, "imath"],
        [306, "IJlig"],
        [307, "ijlig"],
        [308, "Jcirc"],
        [309, "jcirc"],
        [310, "Kcedil"],
        [311, "kcedil"],
        [312, "kgreen"],
        [313, "Lacute"],
        [314, "lacute"],
        [315, "Lcedil"],
        [316, "lcedil"],
        [317, "Lcaron"],
        [318, "lcaron"],
        [319, "Lmidot"],
        [320, "lmidot"],
        [321, "Lstrok"],
        [322, "lstrok"],
        [323, "Nacute"],
        [324, "nacute"],
        [325, "Ncedil"],
        [326, "ncedil"],
        [327, "Ncaron"],
        [328, "ncaron"],
        [329, "napos"],
        [330, "ENG"],
        [331, "eng"],
        [332, "Omacr"],
        [333, "omacr"],
        [336, "Odblac"],
        [337, "odblac"],
        [340, "Racute"],
        [341, "racute"],
        [342, "Rcedil"],
        [343, "rcedil"],
        [344, "Rcaron"],
        [345, "rcaron"],
        [346, "Sacute"],
        [347, "sacute"],
        [348, "Scirc"],
        [349, "scirc"],
        [350, "Scedil"],
        [351, "scedil"],
        [354, "Tcedil"],
        [355, "tcedil"],
        [356, "Tcaron"],
        [357, "tcaron"],
        [358, "Tstrok"],
        [359, "tstrok"],
        [360, "Utilde"],
        [361, "utilde"],
        [362, "Umacr"],
        [363, "umacr"],
        [364, "Ubreve"],
        [365, "ubreve"],
        [366, "Uring"],
        [367, "uring"],
        [368, "Udblac"],
        [369, "udblac"],
        [370, "Uogon"],
        [371, "uogon"],
        [372, "Wcirc"],
        [373, "wcirc"],
        [374, "Ycirc"],
        [375, "ycirc"],
        [377, "Zacute"],
        [378, "zacute"],
        [379, "Zdot"],
        [380, "zdot"],
        [381, "Zcaron"],
        [382, "zcaron"],
        [437, "imped"],
        [501, "gacute"],
        [567, "jmath"],
        [711, "caron"],
        [711, "Hacek"],
        [728, "breve"],
        [728, "Breve"],
        [729, "DiacriticalDot"],
        [729, "dot"],
        [730, "ring"],
        [731, "ogon"],
        [732, "DiacriticalTilde"],
        [733, "dblac"],
        [733, "DiacriticalDoubleAcute"],
        [785, "DownBreve"],
        [937, "ohm"],
        [949, "epsi"],
        [962, "sigmav"],
        [962, "varsigma"],
        [965, "upsi"],
        [977, "vartheta"],
        [977, "thetav"],
        [978, "Upsi"],
        [981, "varphi"],
        [981, "straightphi"],
        [981, "phiv"],
        [982, "varpi"],
        [988, "Gammad"],
        [989, "digamma"],
        [989, "gammad"],
        [1008, "varkappa"],
        [1008, "kappav"],
        [1009, "rhov"],
        [1009, "varrho"],
        [1013, "varepsilon"],
        [1013, "straightepsilon"],
        [1013, "epsiv"],
        [1014, "bepsi"],
        [1014, "backepsilon"],
        [1025, "IOcy"],
        [1026, "DJcy"],
        [1027, "GJcy"],
        [1028, "Jukcy"],
        [1029, "DScy"],
        [1030, "Iukcy"],
        [1031, "YIcy"],
        [1032, "Jsercy"],
        [1033, "LJcy"],
        [1034, "NJcy"],
        [1035, "TSHcy"],
        [1036, "KJcy"],
        [1038, "Ubrcy"],
        [1039, "DZcy"],
        [1040, "Acy"],
        [1041, "Bcy"],
        [1042, "Vcy"],
        [1043, "Gcy"],
        [1044, "Dcy"],
        [1045, "IEcy"],
        [1046, "ZHcy"],
        [1047, "Zcy"],
        [1048, "Icy"],
        [1049, "Jcy"],
        [1050, "Kcy"],
        [1051, "Lcy"],
        [1052, "Mcy"],
        [1053, "Ncy"],
        [1054, "Ocy"],
        [1055, "Pcy"],
        [1056, "Rcy"],
        [1057, "Scy"],
        [1058, "Tcy"],
        [1059, "Ucy"],
        [1060, "Fcy"],
        [1061, "KHcy"],
        [1062, "TScy"],
        [1063, "CHcy"],
        [1064, "SHcy"],
        [1065, "SHCHcy"],
        [1066, "HARDcy"],
        [1067, "Ycy"],
        [1068, "SOFTcy"],
        [1069, "Ecy"],
        [1070, "YUcy"],
        [1071, "YAcy"],
        [1072, "acy"],
        [1073, "bcy"],
        [1074, "vcy"],
        [1075, "gcy"],
        [1076, "dcy"],
        [1077, "iecy"],
        [1078, "zhcy"],
        [1079, "zcy"],
        [1080, "icy"],
        [1081, "jcy"],
        [1082, "kcy"],
        [1083, "lcy"],
        [1084, "mcy"],
        [1085, "ncy"],
        [1086, "ocy"],
        [1087, "pcy"],
        [1088, "rcy"],
        [1089, "scy"],
        [1090, "tcy"],
        [1091, "ucy"],
        [1092, "fcy"],
        [1093, "khcy"],
        [1094, "tscy"],
        [1095, "chcy"],
        [1096, "shcy"],
        [1097, "shchcy"],
        [1098, "hardcy"],
        [1099, "ycy"],
        [1100, "softcy"],
        [1101, "ecy"],
        [1102, "yucy"],
        [1103, "yacy"],
        [1105, "iocy"],
        [1106, "djcy"],
        [1107, "gjcy"],
        [1108, "jukcy"],
        [1109, "dscy"],
        [1110, "iukcy"],
        [1111, "yicy"],
        [1112, "jsercy"],
        [1113, "ljcy"],
        [1114, "njcy"],
        [1115, "tshcy"],
        [1116, "kjcy"],
        [1118, "ubrcy"],
        [1119, "dzcy"],
        [8196, "emsp13"],
        [8197, "emsp14"],
        [8199, "numsp"],
        [8200, "puncsp"],
        [8201, "ThinSpace"],
        [8202, "VeryThinSpace"],
        [8202, "hairsp"],
        [8203, "NegativeThinSpace"],
        [8203, "NegativeThickSpace"],
        [8203, "ZeroWidthSpace"],
        [8203, "NegativeVeryThinSpace"],
        [8203, "NegativeMediumSpace"],
        [8208, "dash"],
        [8208, "hyphen"],
        [8213, "horbar"],
        [8214, "Vert"],
        [8214, "Verbar"],
        [8216, "OpenCurlyQuote"],
        [8217, "CloseCurlyQuote"],
        [8217, "rsquor"],
        [8218, "lsquor"],
        [8220, "OpenCurlyDoubleQuote"],
        [8221, "CloseCurlyDoubleQuote"],
        [8221, "rdquor"],
        [8222, "ldquor"],
        [8225, "ddagger"],
        [8226, "bullet"],
        [8229, "nldr"],
        [8230, "mldr"],
        [8241, "pertenk"],
        [8244, "tprime"],
        [8245, "backprime"],
        [8245, "bprime"],
        [8254, "OverBar"],
        [8257, "caret"],
        [8259, "hybull"],
        [8271, "bsemi"],
        [8279, "qprime"],
        [8287, "MediumSpace"],
        [[8287, 8202], "ThickSpace"],
        [8288, "NoBreak"],
        [8289, "ApplyFunction"],
        [8289, "af"],
        [8290, "it"],
        [8290, "InvisibleTimes"],
        [8291, "ic"],
        [8291, "InvisibleComma"],
        [8411, "TripleDot"],
        [8411, "tdot"],
        [8412, "DotDot"],
        [8450, "Copf"],
        [8450, "complexes"],
        [8453, "incare"],
        [8458, "gscr"],
        [8459, "Hscr"],
        [8459, "HilbertSpace"],
        [8459, "hamilt"],
        [8460, "Poincareplane"],
        [8460, "Hfr"],
        [8461, "quaternions"],
        [8461, "Hopf"],
        [8462, "planckh"],
        [8463, "hslash"],
        [8463, "planck"],
        [8463, "plankv"],
        [8463, "hbar"],
        [8464, "Iscr"],
        [8464, "imagline"],
        [8465, "Im"],
        [8465, "Ifr"],
        [8465, "imagpart"],
        [8466, "Laplacetrf"],
        [8466, "Lscr"],
        [8466, "lagran"],
        [8467, "ell"],
        [8469, "Nopf"],
        [8469, "naturals"],
        [8470, "numero"],
        [8471, "copysr"],
        [8472, "wp"],
        [8473, "primes"],
        [8473, "Popf"],
        [8474, "rationals"],
        [8474, "Qopf"],
        [8475, "realine"],
        [8475, "Rscr"],
        [8476, "realpart"],
        [8476, "Rfr"],
        [8476, "Re"],
        [8477, "reals"],
        [8477, "Ropf"],
        [8478, "rx"],
        [8482, "TRADE"],
        [8484, "integers"],
        [8484, "Zopf"],
        [8487, "mho"],
        [8488, "Zfr"],
        [8488, "zeetrf"],
        [8489, "iiota"],
        [8492, "Bernoullis"],
        [8492, "Bscr"],
        [8492, "bernou"],
        [8493, "Cfr"],
        [8493, "Cayleys"],
        [8495, "escr"],
        [8496, "Escr"],
        [8496, "expectation"],
        [8497, "Fouriertrf"],
        [8497, "Fscr"],
        [8499, "phmmat"],
        [8499, "Mscr"],
        [8499, "Mellintrf"],
        [8500, "orderof"],
        [8500, "order"],
        [8500, "oscr"],
        [8501, "aleph"],
        [8502, "beth"],
        [8503, "gimel"],
        [8504, "daleth"],
        [8517, "DD"],
        [8517, "CapitalDifferentialD"],
        [8518, "DifferentialD"],
        [8518, "dd"],
        [8519, "ExponentialE"],
        [8519, "exponentiale"],
        [8519, "ee"],
        [8520, "ImaginaryI"],
        [8520, "ii"],
        [8531, "frac13"],
        [8532, "frac23"],
        [8533, "frac15"],
        [8534, "frac25"],
        [8535, "frac35"],
        [8536, "frac45"],
        [8537, "frac16"],
        [8538, "frac56"],
        [8539, "frac18"],
        [8540, "frac38"],
        [8541, "frac58"],
        [8542, "frac78"],
        [8592, "LeftArrow"],
        [8592, "slarr"],
        [8592, "ShortLeftArrow"],
        [8592, "leftarrow"],
        [8593, "uparrow"],
        [8593, "UpArrow"],
        [8593, "ShortUpArrow"],
        [8594, "srarr"],
        [8594, "rightarrow"],
        [8594, "RightArrow"],
        [8594, "ShortRightArrow"],
        [8595, "downarrow"],
        [8595, "DownArrow"],
        [8595, "ShortDownArrow"],
        [8596, "LeftRightArrow"],
        [8596, "leftrightarrow"],
        [8597, "UpDownArrow"],
        [8597, "updownarrow"],
        [8597, "varr"],
        [8598, "UpperLeftArrow"],
        [8598, "nwarr"],
        [8598, "nwarrow"],
        [8599, "UpperRightArrow"],
        [8599, "nearr"],
        [8599, "nearrow"],
        [8600, "LowerRightArrow"],
        [8600, "searr"],
        [8600, "searrow"],
        [8601, "LowerLeftArrow"],
        [8601, "swarrow"],
        [8601, "swarr"],
        [8602, "nlarr"],
        [8602, "nleftarrow"],
        [8603, "nrightarrow"],
        [8603, "nrarr"],
        [8605, "rarrw"],
        [8605, "rightsquigarrow"],
        [[8605, 824], "nrarrw"],
        [8606, "Larr"],
        [8606, "twoheadleftarrow"],
        [8607, "Uarr"],
        [8608, "twoheadrightarrow"],
        [8608, "Rarr"],
        [8609, "Darr"],
        [8610, "larrtl"],
        [8610, "leftarrowtail"],
        [8611, "rightarrowtail"],
        [8611, "rarrtl"],
        [8612, "LeftTeeArrow"],
        [8612, "mapstoleft"],
        [8613, "mapstoup"],
        [8613, "UpTeeArrow"],
        [8614, "map"],
        [8614, "RightTeeArrow"],
        [8614, "mapsto"],
        [8615, "mapstodown"],
        [8615, "DownTeeArrow"],
        [8617, "hookleftarrow"],
        [8617, "larrhk"],
        [8618, "rarrhk"],
        [8618, "hookrightarrow"],
        [8619, "larrlp"],
        [8619, "looparrowleft"],
        [8620, "looparrowright"],
        [8620, "rarrlp"],
        [8621, "leftrightsquigarrow"],
        [8621, "harrw"],
        [8622, "nharr"],
        [8622, "nleftrightarrow"],
        [8624, "Lsh"],
        [8624, "lsh"],
        [8625, "rsh"],
        [8625, "Rsh"],
        [8626, "ldsh"],
        [8627, "rdsh"],
        [8630, "cularr"],
        [8630, "curvearrowleft"],
        [8631, "curvearrowright"],
        [8631, "curarr"],
        [8634, "olarr"],
        [8634, "circlearrowleft"],
        [8635, "circlearrowright"],
        [8635, "orarr"],
        [8636, "lharu"],
        [8636, "leftharpoonup"],
        [8636, "LeftVector"],
        [8637, "leftharpoondown"],
        [8637, "DownLeftVector"],
        [8637, "lhard"],
        [8638, "uharr"],
        [8638, "upharpoonright"],
        [8638, "RightUpVector"],
        [8639, "uharl"],
        [8639, "LeftUpVector"],
        [8639, "upharpoonleft"],
        [8640, "rightharpoonup"],
        [8640, "rharu"],
        [8640, "RightVector"],
        [8641, "rhard"],
        [8641, "DownRightVector"],
        [8641, "rightharpoondown"],
        [8642, "downharpoonright"],
        [8642, "RightDownVector"],
        [8642, "dharr"],
        [8643, "downharpoonleft"],
        [8643, "dharl"],
        [8643, "LeftDownVector"],
        [8644, "RightArrowLeftArrow"],
        [8644, "rightleftarrows"],
        [8644, "rlarr"],
        [8645, "UpArrowDownArrow"],
        [8645, "udarr"],
        [8646, "leftrightarrows"],
        [8646, "LeftArrowRightArrow"],
        [8646, "lrarr"],
        [8647, "leftleftarrows"],
        [8647, "llarr"],
        [8648, "uuarr"],
        [8648, "upuparrows"],
        [8649, "rightrightarrows"],
        [8649, "rrarr"],
        [8650, "downdownarrows"],
        [8650, "ddarr"],
        [8651, "lrhar"],
        [8651, "ReverseEquilibrium"],
        [8651, "leftrightharpoons"],
        [8652, "rightleftharpoons"],
        [8652, "Equilibrium"],
        [8652, "rlhar"],
        [8653, "nLeftarrow"],
        [8653, "nlArr"],
        [8654, "nLeftrightarrow"],
        [8654, "nhArr"],
        [8655, "nrArr"],
        [8655, "nRightarrow"],
        [8656, "Leftarrow"],
        [8656, "DoubleLeftArrow"],
        [8657, "DoubleUpArrow"],
        [8657, "Uparrow"],
        [8658, "Implies"],
        [8658, "Rightarrow"],
        [8658, "DoubleRightArrow"],
        [8659, "Downarrow"],
        [8659, "DoubleDownArrow"],
        [8660, "iff"],
        [8660, "Leftrightarrow"],
        [8660, "DoubleLeftRightArrow"],
        [8661, "vArr"],
        [8661, "Updownarrow"],
        [8661, "DoubleUpDownArrow"],
        [8662, "nwArr"],
        [8663, "neArr"],
        [8664, "seArr"],
        [8665, "swArr"],
        [8666, "lAarr"],
        [8666, "Lleftarrow"],
        [8667, "Rrightarrow"],
        [8667, "rAarr"],
        [8669, "zigrarr"],
        [8676, "larrb"],
        [8676, "LeftArrowBar"],
        [8677, "rarrb"],
        [8677, "RightArrowBar"],
        [8693, "duarr"],
        [8693, "DownArrowUpArrow"],
        [8701, "loarr"],
        [8702, "roarr"],
        [8703, "hoarr"],
        [8704, "ForAll"],
        [8705, "comp"],
        [8705, "complement"],
        [8706, "PartialD"],
        [[8706, 824], "npart"],
        [8707, "Exists"],
        [8708, "nexist"],
        [8708, "nexists"],
        [8708, "NotExists"],
        [8709, "emptyv"],
        [8709, "emptyset"],
        [8709, "varnothing"],
        [8711, "Del"],
        [8712, "in"],
        [8712, "isinv"],
        [8712, "Element"],
        [8713, "NotElement"],
        [8713, "notinva"],
        [8715, "ReverseElement"],
        [8715, "SuchThat"],
        [8715, "niv"],
        [8716, "NotReverseElement"],
        [8716, "notniva"],
        [8716, "notni"],
        [8719, "Product"],
        [8720, "Coproduct"],
        [8720, "coprod"],
        [8721, "Sum"],
        [8723, "mp"],
        [8723, "mnplus"],
        [8723, "MinusPlus"],
        [8724, "dotplus"],
        [8724, "plusdo"],
        [8726, "setminus"],
        [8726, "ssetmn"],
        [8726, "setmn"],
        [8726, "smallsetminus"],
        [8726, "Backslash"],
        [8728, "SmallCircle"],
        [8728, "compfn"],
        [8730, "Sqrt"],
        [8733, "varpropto"],
        [8733, "Proportional"],
        [8733, "propto"],
        [8733, "vprop"],
        [8735, "angrt"],
        [8736, "angle"],
        [[8736, 8402], "nang"],
        [8737, "measuredangle"],
        [8737, "angmsd"],
        [8738, "angsph"],
        [8739, "shortmid"],
        [8739, "mid"],
        [8739, "VerticalBar"],
        [8739, "smid"],
        [8740, "nsmid"],
        [8740, "nmid"],
        [8740, "nshortmid"],
        [8740, "NotVerticalBar"],
        [8741, "shortparallel"],
        [8741, "spar"],
        [8741, "DoubleVerticalBar"],
        [8741, "par"],
        [8741, "parallel"],
        [8742, "nshortparallel"],
        [8742, "nparallel"],
        [8742, "npar"],
        [8742, "nspar"],
        [8742, "NotDoubleVerticalBar"],
        [8743, "wedge"],
        [8744, "vee"],
        [8745, "cap"],
        [[8745, 65024], "caps"],
        [8746, "cup"],
        [[8746, 65024], "cups"],
        [8747, "Integral"],
        [8748, "Int"],
        [8749, "iiint"],
        [8749, "tint"],
        [8750, "oint"],
        [8750, "ContourIntegral"],
        [8750, "conint"],
        [8751, "Conint"],
        [8751, "DoubleContourIntegral"],
        [8752, "Cconint"],
        [8753, "cwint"],
        [8754, "ClockwiseContourIntegral"],
        [8754, "cwconint"],
        [8755, "CounterClockwiseContourIntegral"],
        [8755, "awconint"],
        [8756, "therefore"],
        [8756, "Therefore"],
        [8757, "becaus"],
        [8757, "Because"],
        [8757, "because"],
        [8758, "ratio"],
        [8759, "Proportion"],
        [8759, "Colon"],
        [8760, "minusd"],
        [8760, "dotminus"],
        [8762, "mDDot"],
        [8763, "homtht"],
        [8764, "thksim"],
        [8764, "Tilde"],
        [8764, "thicksim"],
        [[8764, 8402], "nvsim"],
        [8765, "backsim"],
        [8765, "bsim"],
        [[8765, 817], "race"],
        [8766, "mstpos"],
        [8766, "ac"],
        [[8766, 819], "acE"],
        [8767, "acd"],
        [8768, "wr"],
        [8768, "VerticalTilde"],
        [8768, "wreath"],
        [8769, "NotTilde"],
        [8769, "nsim"],
        [8770, "eqsim"],
        [8770, "esim"],
        [8770, "EqualTilde"],
        [[8770, 824], "NotEqualTilde"],
        [[8770, 824], "nesim"],
        [8771, "simeq"],
        [8771, "TildeEqual"],
        [8771, "sime"],
        [8772, "nsimeq"],
        [8772, "nsime"],
        [8772, "NotTildeEqual"],
        [8773, "TildeFullEqual"],
        [8774, "simne"],
        [8775, "ncong"],
        [8775, "NotTildeFullEqual"],
        [8776, "thickapprox"],
        [8776, "ap"],
        [8776, "TildeTilde"],
        [8776, "thkap"],
        [8776, "approx"],
        [8777, "napprox"],
        [8777, "NotTildeTilde"],
        [8777, "nap"],
        [8778, "ape"],
        [8778, "approxeq"],
        [8779, "apid"],
        [[8779, 824], "napid"],
        [8780, "bcong"],
        [8780, "backcong"],
        [8781, "asympeq"],
        [8781, "CupCap"],
        [[8781, 8402], "nvap"],
        [8782, "HumpDownHump"],
        [8782, "Bumpeq"],
        [8782, "bump"],
        [[8782, 824], "nbump"],
        [[8782, 824], "NotHumpDownHump"],
        [8783, "bumpe"],
        [8783, "HumpEqual"],
        [8783, "bumpeq"],
        [[8783, 824], "nbumpe"],
        [[8783, 824], "NotHumpEqual"],
        [8784, "esdot"],
        [8784, "DotEqual"],
        [8784, "doteq"],
        [[8784, 824], "nedot"],
        [8785, "eDot"],
        [8785, "doteqdot"],
        [8786, "fallingdotseq"],
        [8786, "efDot"],
        [8787, "erDot"],
        [8787, "risingdotseq"],
        [8788, "Assign"],
        [8788, "colone"],
        [8788, "coloneq"],
        [8789, "ecolon"],
        [8789, "eqcolon"],
        [8790, "ecir"],
        [8790, "eqcirc"],
        [8791, "circeq"],
        [8791, "cire"],
        [8793, "wedgeq"],
        [8794, "veeeq"],
        [8796, "trie"],
        [8796, "triangleq"],
        [8799, "questeq"],
        [8799, "equest"],
        [8800, "NotEqual"],
        [8801, "Congruent"],
        [[8801, 8421], "bnequiv"],
        [8802, "nequiv"],
        [8802, "NotCongruent"],
        [8804, "leq"],
        [[8804, 8402], "nvle"],
        [8805, "GreaterEqual"],
        [8805, "geq"],
        [[8805, 8402], "nvge"],
        [8806, "leqq"],
        [8806, "lE"],
        [8806, "LessFullEqual"],
        [[8806, 824], "nlE"],
        [[8806, 824], "nleqq"],
        [8807, "gE"],
        [8807, "GreaterFullEqual"],
        [8807, "geqq"],
        [[8807, 824], "NotGreaterFullEqual"],
        [[8807, 824], "ngeqq"],
        [[8807, 824], "ngE"],
        [8808, "lneqq"],
        [8808, "lnE"],
        [[8808, 65024], "lvertneqq"],
        [[8808, 65024], "lvnE"],
        [8809, "gnE"],
        [8809, "gneqq"],
        [[8809, 65024], "gvnE"],
        [[8809, 65024], "gvertneqq"],
        [8810, "NestedLessLess"],
        [8810, "ll"],
        [8810, "Lt"],
        [[8810, 824], "NotLessLess"],
        [[8810, 824], "nLtv"],
        [[8810, 8402], "nLt"],
        [8811, "Gt"],
        [8811, "gg"],
        [8811, "NestedGreaterGreater"],
        [[8811, 824], "NotGreaterGreater"],
        [[8811, 824], "nGtv"],
        [[8811, 8402], "nGt"],
        [8812, "between"],
        [8812, "twixt"],
        [8813, "NotCupCap"],
        [8814, "NotLess"],
        [8814, "nless"],
        [8814, "nlt"],
        [8815, "ngt"],
        [8815, "NotGreater"],
        [8815, "ngtr"],
        [8816, "nle"],
        [8816, "nleq"],
        [8816, "NotLessEqual"],
        [8817, "NotGreaterEqual"],
        [8817, "nge"],
        [8817, "ngeq"],
        [8818, "LessTilde"],
        [8818, "lsim"],
        [8818, "lesssim"],
        [8819, "gtrsim"],
        [8819, "gsim"],
        [8819, "GreaterTilde"],
        [8820, "NotLessTilde"],
        [8820, "nlsim"],
        [8821, "NotGreaterTilde"],
        [8821, "ngsim"],
        [8822, "LessGreater"],
        [8822, "lessgtr"],
        [8822, "lg"],
        [8823, "gtrless"],
        [8823, "GreaterLess"],
        [8823, "gl"],
        [8824, "ntlg"],
        [8824, "NotLessGreater"],
        [8825, "NotGreaterLess"],
        [8825, "ntgl"],
        [8826, "prec"],
        [8826, "pr"],
        [8826, "Precedes"],
        [8827, "Succeeds"],
        [8827, "succ"],
        [8827, "sc"],
        [8828, "PrecedesSlantEqual"],
        [8828, "preccurlyeq"],
        [8828, "prcue"],
        [8829, "sccue"],
        [8829, "SucceedsSlantEqual"],
        [8829, "succcurlyeq"],
        [8830, "prsim"],
        [8830, "PrecedesTilde"],
        [8830, "precsim"],
        [8831, "succsim"],
        [8831, "scsim"],
        [8831, "SucceedsTilde"],
        [[8831, 824], "NotSucceedsTilde"],
        [8832, "NotPrecedes"],
        [8832, "npr"],
        [8832, "nprec"],
        [8833, "NotSucceeds"],
        [8833, "nsucc"],
        [8833, "nsc"],
        [8834, "subset"],
        [[8834, 8402], "NotSubset"],
        [[8834, 8402], "vnsub"],
        [[8834, 8402], "nsubset"],
        [8835, "Superset"],
        [8835, "supset"],
        [[8835, 8402], "NotSuperset"],
        [[8835, 8402], "nsupset"],
        [[8835, 8402], "vnsup"],
        [8837, "nsup"],
        [8838, "subseteq"],
        [8838, "SubsetEqual"],
        [8839, "SupersetEqual"],
        [8839, "supseteq"],
        [8840, "nsubseteq"],
        [8840, "NotSubsetEqual"],
        [8840, "nsube"],
        [8841, "NotSupersetEqual"],
        [8841, "nsupseteq"],
        [8841, "nsupe"],
        [8842, "subsetneq"],
        [8842, "subne"],
        [[8842, 65024], "vsubne"],
        [[8842, 65024], "varsubsetneq"],
        [8843, "supne"],
        [8843, "supsetneq"],
        [[8843, 65024], "vsupne"],
        [[8843, 65024], "varsupsetneq"],
        [8845, "cupdot"],
        [8846, "UnionPlus"],
        [8846, "uplus"],
        [8847, "SquareSubset"],
        [8847, "sqsub"],
        [8847, "sqsubset"],
        [[8847, 824], "NotSquareSubset"],
        [8848, "SquareSuperset"],
        [8848, "sqsupset"],
        [8848, "sqsup"],
        [[8848, 824], "NotSquareSuperset"],
        [8849, "sqsubseteq"],
        [8849, "sqsube"],
        [8849, "SquareSubsetEqual"],
        [8850, "SquareSupersetEqual"],
        [8850, "sqsupe"],
        [8850, "sqsupseteq"],
        [8851, "SquareIntersection"],
        [8851, "sqcap"],
        [[8851, 65024], "sqcaps"],
        [8852, "SquareUnion"],
        [8852, "sqcup"],
        [[8852, 65024], "sqcups"],
        [8853, "CirclePlus"],
        [8854, "ominus"],
        [8854, "CircleMinus"],
        [8855, "CircleTimes"],
        [8856, "osol"],
        [8857, "odot"],
        [8857, "CircleDot"],
        [8858, "circledcirc"],
        [8858, "ocir"],
        [8859, "oast"],
        [8859, "circledast"],
        [8861, "circleddash"],
        [8861, "odash"],
        [8862, "boxplus"],
        [8862, "plusb"],
        [8863, "boxminus"],
        [8863, "minusb"],
        [8864, "boxtimes"],
        [8864, "timesb"],
        [8865, "sdotb"],
        [8865, "dotsquare"],
        [8866, "vdash"],
        [8866, "RightTee"],
        [8867, "LeftTee"],
        [8867, "dashv"],
        [8868, "top"],
        [8868, "DownTee"],
        [8869, "bottom"],
        [8869, "UpTee"],
        [8869, "bot"],
        [8871, "models"],
        [8872, "DoubleRightTee"],
        [8872, "vDash"],
        [8873, "Vdash"],
        [8874, "Vvdash"],
        [8875, "VDash"],
        [8876, "nvdash"],
        [8877, "nvDash"],
        [8878, "nVdash"],
        [8879, "nVDash"],
        [8880, "prurel"],
        [8882, "LeftTriangle"],
        [8882, "vltri"],
        [8882, "vartriangleleft"],
        [8883, "RightTriangle"],
        [8883, "vrtri"],
        [8883, "vartriangleright"],
        [8884, "LeftTriangleEqual"],
        [8884, "ltrie"],
        [8884, "trianglelefteq"],
        [[8884, 8402], "nvltrie"],
        [8885, "trianglerighteq"],
        [8885, "RightTriangleEqual"],
        [8885, "rtrie"],
        [[8885, 8402], "nvrtrie"],
        [8886, "origof"],
        [8887, "imof"],
        [8888, "multimap"],
        [8888, "mumap"],
        [8889, "hercon"],
        [8890, "intercal"],
        [8890, "intcal"],
        [8891, "veebar"],
        [8893, "barvee"],
        [8894, "angrtvb"],
        [8895, "lrtri"],
        [8896, "xwedge"],
        [8896, "bigwedge"],
        [8896, "Wedge"],
        [8897, "xvee"],
        [8897, "Vee"],
        [8897, "bigvee"],
        [8898, "xcap"],
        [8898, "bigcap"],
        [8898, "Intersection"],
        [8899, "Union"],
        [8899, "bigcup"],
        [8899, "xcup"],
        [8900, "diam"],
        [8900, "diamond"],
        [8900, "Diamond"],
        [8902, "sstarf"],
        [8902, "Star"],
        [8903, "divonx"],
        [8903, "divideontimes"],
        [8904, "bowtie"],
        [8905, "ltimes"],
        [8906, "rtimes"],
        [8907, "leftthreetimes"],
        [8907, "lthree"],
        [8908, "rightthreetimes"],
        [8908, "rthree"],
        [8909, "bsime"],
        [8909, "backsimeq"],
        [8910, "curlyvee"],
        [8910, "cuvee"],
        [8911, "curlywedge"],
        [8911, "cuwed"],
        [8912, "Subset"],
        [8912, "Sub"],
        [8913, "Sup"],
        [8913, "Supset"],
        [8914, "Cap"],
        [8915, "Cup"],
        [8916, "fork"],
        [8916, "pitchfork"],
        [8917, "epar"],
        [8918, "ltdot"],
        [8918, "lessdot"],
        [8919, "gtdot"],
        [8919, "gtrdot"],
        [8920, "Ll"],
        [[8920, 824], "nLl"],
        [8921, "ggg"],
        [8921, "Gg"],
        [[8921, 824], "nGg"],
        [8922, "lesseqgtr"],
        [8922, "LessEqualGreater"],
        [8922, "leg"],
        [[8922, 65024], "lesg"],
        [8923, "GreaterEqualLess"],
        [8923, "gtreqless"],
        [8923, "gel"],
        [[8923, 65024], "gesl"],
        [8926, "curlyeqprec"],
        [8926, "cuepr"],
        [8927, "cuesc"],
        [8927, "curlyeqsucc"],
        [8928, "nprcue"],
        [8928, "NotPrecedesSlantEqual"],
        [8929, "nsccue"],
        [8929, "NotSucceedsSlantEqual"],
        [8930, "nsqsube"],
        [8930, "NotSquareSubsetEqual"],
        [8931, "NotSquareSupersetEqual"],
        [8931, "nsqsupe"],
        [8934, "lnsim"],
        [8935, "gnsim"],
        [8936, "prnsim"],
        [8936, "precnsim"],
        [8937, "succnsim"],
        [8937, "scnsim"],
        [8938, "NotLeftTriangle"],
        [8938, "nltri"],
        [8938, "ntriangleleft"],
        [8939, "nrtri"],
        [8939, "NotRightTriangle"],
        [8939, "ntriangleright"],
        [8940, "nltrie"],
        [8940, "ntrianglelefteq"],
        [8940, "NotLeftTriangleEqual"],
        [8941, "ntrianglerighteq"],
        [8941, "nrtrie"],
        [8941, "NotRightTriangleEqual"],
        [8943, "ctdot"],
        [8944, "utdot"],
        [8945, "dtdot"],
        [8946, "disin"],
        [8947, "isinsv"],
        [8948, "isins"],
        [8949, "isindot"],
        [[8949, 824], "notindot"],
        [8950, "notinvc"],
        [8951, "notinvb"],
        [8953, "isinE"],
        [[8953, 824], "notinE"],
        [8954, "nisd"],
        [8955, "xnis"],
        [8956, "nis"],
        [8957, "notnivc"],
        [8958, "notnivb"],
        [8965, "barwed"],
        [8965, "barwedge"],
        [8966, "Barwed"],
        [8966, "doublebarwedge"],
        [8968, "lceil"],
        [8968, "LeftCeiling"],
        [8969, "rceil"],
        [8969, "RightCeiling"],
        [8970, "LeftFloor"],
        [8971, "RightFloor"],
        [8972, "drcrop"],
        [8973, "dlcrop"],
        [8974, "urcrop"],
        [8975, "ulcrop"],
        [8976, "bnot"],
        [8978, "profline"],
        [8979, "profsurf"],
        [8981, "telrec"],
        [8982, "target"],
        [8988, "ulcorn"],
        [8988, "ulcorner"],
        [8989, "urcorn"],
        [8989, "urcorner"],
        [8990, "llcorner"],
        [8990, "dlcorn"],
        [8991, "lrcorner"],
        [8991, "drcorn"],
        [8994, "frown"],
        [8994, "sfrown"],
        [8995, "ssmile"],
        [8995, "smile"],
        [9005, "cylcty"],
        [9006, "profalar"],
        [9014, "topbot"],
        [9021, "ovbar"],
        [9023, "solbar"],
        [9084, "angzarr"],
        [9136, "lmoustache"],
        [9136, "lmoust"],
        [9137, "rmoust"],
        [9137, "rmoustache"],
        [9140, "tbrk"],
        [9140, "OverBracket"],
        [9141, "bbrk"],
        [9141, "UnderBracket"],
        [9142, "bbrktbrk"],
        [9180, "OverParenthesis"],
        [9181, "UnderParenthesis"],
        [9182, "OverBrace"],
        [9183, "UnderBrace"],
        [9186, "trpezium"],
        [9191, "elinters"],
        [9251, "blank"],
        [9416, "circledS"],
        [9416, "oS"],
        [9472, "boxh"],
        [9472, "HorizontalLine"],
        [9474, "boxv"],
        [9484, "boxdr"],
        [9488, "boxdl"],
        [9492, "boxur"],
        [9496, "boxul"],
        [9500, "boxvr"],
        [9508, "boxvl"],
        [9516, "boxhd"],
        [9524, "boxhu"],
        [9532, "boxvh"],
        [9552, "boxH"],
        [9553, "boxV"],
        [9554, "boxdR"],
        [9555, "boxDr"],
        [9556, "boxDR"],
        [9557, "boxdL"],
        [9558, "boxDl"],
        [9559, "boxDL"],
        [9560, "boxuR"],
        [9561, "boxUr"],
        [9562, "boxUR"],
        [9563, "boxuL"],
        [9564, "boxUl"],
        [9565, "boxUL"],
        [9566, "boxvR"],
        [9567, "boxVr"],
        [9568, "boxVR"],
        [9569, "boxvL"],
        [9570, "boxVl"],
        [9571, "boxVL"],
        [9572, "boxHd"],
        [9573, "boxhD"],
        [9574, "boxHD"],
        [9575, "boxHu"],
        [9576, "boxhU"],
        [9577, "boxHU"],
        [9578, "boxvH"],
        [9579, "boxVh"],
        [9580, "boxVH"],
        [9600, "uhblk"],
        [9604, "lhblk"],
        [9608, "block"],
        [9617, "blk14"],
        [9618, "blk12"],
        [9619, "blk34"],
        [9633, "squ"],
        [9633, "square"],
        [9633, "Square"],
        [9642, "blacksquare"],
        [9642, "FilledVerySmallSquare"],
        [9642, "squf"],
        [9642, "squarf"],
        [9643, "EmptyVerySmallSquare"],
        [9645, "rect"],
        [9646, "marker"],
        [9649, "fltns"],
        [9651, "xutri"],
        [9651, "bigtriangleup"],
        [9652, "blacktriangle"],
        [9652, "utrif"],
        [9653, "triangle"],
        [9653, "utri"],
        [9656, "rtrif"],
        [9656, "blacktriangleright"],
        [9657, "rtri"],
        [9657, "triangleright"],
        [9661, "xdtri"],
        [9661, "bigtriangledown"],
        [9662, "blacktriangledown"],
        [9662, "dtrif"],
        [9663, "triangledown"],
        [9663, "dtri"],
        [9666, "blacktriangleleft"],
        [9666, "ltrif"],
        [9667, "ltri"],
        [9667, "triangleleft"],
        [9674, "lozenge"],
        [9675, "cir"],
        [9708, "tridot"],
        [9711, "bigcirc"],
        [9711, "xcirc"],
        [9720, "ultri"],
        [9721, "urtri"],
        [9722, "lltri"],
        [9723, "EmptySmallSquare"],
        [9724, "FilledSmallSquare"],
        [9733, "starf"],
        [9733, "bigstar"],
        [9734, "star"],
        [9742, "phone"],
        [9792, "female"],
        [9794, "male"],
        [9824, "spadesuit"],
        [9827, "clubsuit"],
        [9829, "heartsuit"],
        [9830, "diamondsuit"],
        [9834, "sung"],
        [9837, "flat"],
        [9838, "natur"],
        [9838, "natural"],
        [9839, "sharp"],
        [10003, "checkmark"],
        [10003, "check"],
        [10007, "cross"],
        [10016, "malt"],
        [10016, "maltese"],
        [10038, "sext"],
        [10072, "VerticalSeparator"],
        [10098, "lbbrk"],
        [10099, "rbbrk"],
        [10184, "bsolhsub"],
        [10185, "suphsol"],
        [10214, "LeftDoubleBracket"],
        [10214, "lobrk"],
        [10215, "RightDoubleBracket"],
        [10215, "robrk"],
        [10216, "lang"],
        [10216, "langle"],
        [10216, "LeftAngleBracket"],
        [10217, "rang"],
        [10217, "RightAngleBracket"],
        [10217, "rangle"],
        [10218, "Lang"],
        [10219, "Rang"],
        [10220, "loang"],
        [10221, "roang"],
        [10229, "LongLeftArrow"],
        [10229, "xlarr"],
        [10229, "longleftarrow"],
        [10230, "LongRightArrow"],
        [10230, "xrarr"],
        [10230, "longrightarrow"],
        [10231, "longleftrightarrow"],
        [10231, "LongLeftRightArrow"],
        [10231, "xharr"],
        [10232, "Longleftarrow"],
        [10232, "xlArr"],
        [10232, "DoubleLongLeftArrow"],
        [10233, "Longrightarrow"],
        [10233, "DoubleLongRightArrow"],
        [10233, "xrArr"],
        [10234, "xhArr"],
        [10234, "Longleftrightarrow"],
        [10234, "DoubleLongLeftRightArrow"],
        [10236, "xmap"],
        [10236, "longmapsto"],
        [10239, "dzigrarr"],
        [10498, "nvlArr"],
        [10499, "nvrArr"],
        [10500, "nvHarr"],
        [10501, "Map"],
        [10508, "lbarr"],
        [10509, "rbarr"],
        [10509, "bkarow"],
        [10510, "lBarr"],
        [10511, "rBarr"],
        [10511, "dbkarow"],
        [10512, "drbkarow"],
        [10512, "RBarr"],
        [10513, "DDotrahd"],
        [10514, "UpArrowBar"],
        [10515, "DownArrowBar"],
        [10518, "Rarrtl"],
        [10521, "latail"],
        [10522, "ratail"],
        [10523, "lAtail"],
        [10524, "rAtail"],
        [10525, "larrfs"],
        [10526, "rarrfs"],
        [10527, "larrbfs"],
        [10528, "rarrbfs"],
        [10531, "nwarhk"],
        [10532, "nearhk"],
        [10533, "searhk"],
        [10533, "hksearow"],
        [10534, "swarhk"],
        [10534, "hkswarow"],
        [10535, "nwnear"],
        [10536, "nesear"],
        [10536, "toea"],
        [10537, "tosa"],
        [10537, "seswar"],
        [10538, "swnwar"],
        [10547, "rarrc"],
        [[10547, 824], "nrarrc"],
        [10549, "cudarrr"],
        [10550, "ldca"],
        [10551, "rdca"],
        [10552, "cudarrl"],
        [10553, "larrpl"],
        [10556, "curarrm"],
        [10557, "cularrp"],
        [10565, "rarrpl"],
        [10568, "harrcir"],
        [10569, "Uarrocir"],
        [10570, "lurdshar"],
        [10571, "ldrushar"],
        [10574, "LeftRightVector"],
        [10575, "RightUpDownVector"],
        [10576, "DownLeftRightVector"],
        [10577, "LeftUpDownVector"],
        [10578, "LeftVectorBar"],
        [10579, "RightVectorBar"],
        [10580, "RightUpVectorBar"],
        [10581, "RightDownVectorBar"],
        [10582, "DownLeftVectorBar"],
        [10583, "DownRightVectorBar"],
        [10584, "LeftUpVectorBar"],
        [10585, "LeftDownVectorBar"],
        [10586, "LeftTeeVector"],
        [10587, "RightTeeVector"],
        [10588, "RightUpTeeVector"],
        [10589, "RightDownTeeVector"],
        [10590, "DownLeftTeeVector"],
        [10591, "DownRightTeeVector"],
        [10592, "LeftUpTeeVector"],
        [10593, "LeftDownTeeVector"],
        [10594, "lHar"],
        [10595, "uHar"],
        [10596, "rHar"],
        [10597, "dHar"],
        [10598, "luruhar"],
        [10599, "ldrdhar"],
        [10600, "ruluhar"],
        [10601, "rdldhar"],
        [10602, "lharul"],
        [10603, "llhard"],
        [10604, "rharul"],
        [10605, "lrhard"],
        [10606, "udhar"],
        [10606, "UpEquilibrium"],
        [10607, "duhar"],
        [10607, "ReverseUpEquilibrium"],
        [10608, "RoundImplies"],
        [10609, "erarr"],
        [10610, "simrarr"],
        [10611, "larrsim"],
        [10612, "rarrsim"],
        [10613, "rarrap"],
        [10614, "ltlarr"],
        [10616, "gtrarr"],
        [10617, "subrarr"],
        [10619, "suplarr"],
        [10620, "lfisht"],
        [10621, "rfisht"],
        [10622, "ufisht"],
        [10623, "dfisht"],
        [10629, "lopar"],
        [10630, "ropar"],
        [10635, "lbrke"],
        [10636, "rbrke"],
        [10637, "lbrkslu"],
        [10638, "rbrksld"],
        [10639, "lbrksld"],
        [10640, "rbrkslu"],
        [10641, "langd"],
        [10642, "rangd"],
        [10643, "lparlt"],
        [10644, "rpargt"],
        [10645, "gtlPar"],
        [10646, "ltrPar"],
        [10650, "vzigzag"],
        [10652, "vangrt"],
        [10653, "angrtvbd"],
        [10660, "ange"],
        [10661, "range"],
        [10662, "dwangle"],
        [10663, "uwangle"],
        [10664, "angmsdaa"],
        [10665, "angmsdab"],
        [10666, "angmsdac"],
        [10667, "angmsdad"],
        [10668, "angmsdae"],
        [10669, "angmsdaf"],
        [10670, "angmsdag"],
        [10671, "angmsdah"],
        [10672, "bemptyv"],
        [10673, "demptyv"],
        [10674, "cemptyv"],
        [10675, "raemptyv"],
        [10676, "laemptyv"],
        [10677, "ohbar"],
        [10678, "omid"],
        [10679, "opar"],
        [10681, "operp"],
        [10683, "olcross"],
        [10684, "odsold"],
        [10686, "olcir"],
        [10687, "ofcir"],
        [10688, "olt"],
        [10689, "ogt"],
        [10690, "cirscir"],
        [10691, "cirE"],
        [10692, "solb"],
        [10693, "bsolb"],
        [10697, "boxbox"],
        [10701, "trisb"],
        [10702, "rtriltri"],
        [10703, "LeftTriangleBar"],
        [[10703, 824], "NotLeftTriangleBar"],
        [10704, "RightTriangleBar"],
        [[10704, 824], "NotRightTriangleBar"],
        [10716, "iinfin"],
        [10717, "infintie"],
        [10718, "nvinfin"],
        [10723, "eparsl"],
        [10724, "smeparsl"],
        [10725, "eqvparsl"],
        [10731, "lozf"],
        [10731, "blacklozenge"],
        [10740, "RuleDelayed"],
        [10742, "dsol"],
        [10752, "xodot"],
        [10752, "bigodot"],
        [10753, "xoplus"],
        [10753, "bigoplus"],
        [10754, "xotime"],
        [10754, "bigotimes"],
        [10756, "xuplus"],
        [10756, "biguplus"],
        [10758, "bigsqcup"],
        [10758, "xsqcup"],
        [10764, "qint"],
        [10764, "iiiint"],
        [10765, "fpartint"],
        [10768, "cirfnint"],
        [10769, "awint"],
        [10770, "rppolint"],
        [10771, "scpolint"],
        [10772, "npolint"],
        [10773, "pointint"],
        [10774, "quatint"],
        [10775, "intlarhk"],
        [10786, "pluscir"],
        [10787, "plusacir"],
        [10788, "simplus"],
        [10789, "plusdu"],
        [10790, "plussim"],
        [10791, "plustwo"],
        [10793, "mcomma"],
        [10794, "minusdu"],
        [10797, "loplus"],
        [10798, "roplus"],
        [10799, "Cross"],
        [10800, "timesd"],
        [10801, "timesbar"],
        [10803, "smashp"],
        [10804, "lotimes"],
        [10805, "rotimes"],
        [10806, "otimesas"],
        [10807, "Otimes"],
        [10808, "odiv"],
        [10809, "triplus"],
        [10810, "triminus"],
        [10811, "tritime"],
        [10812, "intprod"],
        [10812, "iprod"],
        [10815, "amalg"],
        [10816, "capdot"],
        [10818, "ncup"],
        [10819, "ncap"],
        [10820, "capand"],
        [10821, "cupor"],
        [10822, "cupcap"],
        [10823, "capcup"],
        [10824, "cupbrcap"],
        [10825, "capbrcup"],
        [10826, "cupcup"],
        [10827, "capcap"],
        [10828, "ccups"],
        [10829, "ccaps"],
        [10832, "ccupssm"],
        [10835, "And"],
        [10836, "Or"],
        [10837, "andand"],
        [10838, "oror"],
        [10839, "orslope"],
        [10840, "andslope"],
        [10842, "andv"],
        [10843, "orv"],
        [10844, "andd"],
        [10845, "ord"],
        [10847, "wedbar"],
        [10854, "sdote"],
        [10858, "simdot"],
        [10861, "congdot"],
        [[10861, 824], "ncongdot"],
        [10862, "easter"],
        [10863, "apacir"],
        [10864, "apE"],
        [[10864, 824], "napE"],
        [10865, "eplus"],
        [10866, "pluse"],
        [10867, "Esim"],
        [10868, "Colone"],
        [10869, "Equal"],
        [10871, "eDDot"],
        [10871, "ddotseq"],
        [10872, "equivDD"],
        [10873, "ltcir"],
        [10874, "gtcir"],
        [10875, "ltquest"],
        [10876, "gtquest"],
        [10877, "les"],
        [10877, "LessSlantEqual"],
        [10877, "leqslant"],
        [[10877, 824], "nleqslant"],
        [[10877, 824], "NotLessSlantEqual"],
        [[10877, 824], "nles"],
        [10878, "GreaterSlantEqual"],
        [10878, "ges"],
        [10878, "geqslant"],
        [[10878, 824], "NotGreaterSlantEqual"],
        [[10878, 824], "ngeqslant"],
        [[10878, 824], "nges"],
        [10879, "lesdot"],
        [10880, "gesdot"],
        [10881, "lesdoto"],
        [10882, "gesdoto"],
        [10883, "lesdotor"],
        [10884, "gesdotol"],
        [10885, "lap"],
        [10885, "lessapprox"],
        [10886, "gap"],
        [10886, "gtrapprox"],
        [10887, "lneq"],
        [10887, "lne"],
        [10888, "gne"],
        [10888, "gneq"],
        [10889, "lnap"],
        [10889, "lnapprox"],
        [10890, "gnapprox"],
        [10890, "gnap"],
        [10891, "lesseqqgtr"],
        [10891, "lEg"],
        [10892, "gtreqqless"],
        [10892, "gEl"],
        [10893, "lsime"],
        [10894, "gsime"],
        [10895, "lsimg"],
        [10896, "gsiml"],
        [10897, "lgE"],
        [10898, "glE"],
        [10899, "lesges"],
        [10900, "gesles"],
        [10901, "els"],
        [10901, "eqslantless"],
        [10902, "egs"],
        [10902, "eqslantgtr"],
        [10903, "elsdot"],
        [10904, "egsdot"],
        [10905, "el"],
        [10906, "eg"],
        [10909, "siml"],
        [10910, "simg"],
        [10911, "simlE"],
        [10912, "simgE"],
        [10913, "LessLess"],
        [[10913, 824], "NotNestedLessLess"],
        [10914, "GreaterGreater"],
        [[10914, 824], "NotNestedGreaterGreater"],
        [10916, "glj"],
        [10917, "gla"],
        [10918, "ltcc"],
        [10919, "gtcc"],
        [10920, "lescc"],
        [10921, "gescc"],
        [10922, "smt"],
        [10923, "lat"],
        [10924, "smte"],
        [[10924, 65024], "smtes"],
        [10925, "late"],
        [[10925, 65024], "lates"],
        [10926, "bumpE"],
        [10927, "preceq"],
        [10927, "PrecedesEqual"],
        [10927, "pre"],
        [[10927, 824], "npreceq"],
        [[10927, 824], "NotPrecedesEqual"],
        [[10927, 824], "npre"],
        [10928, "sce"],
        [10928, "succeq"],
        [10928, "SucceedsEqual"],
        [[10928, 824], "nsucceq"],
        [[10928, 824], "NotSucceedsEqual"],
        [[10928, 824], "nsce"],
        [10931, "prE"],
        [10932, "scE"],
        [10933, "prnE"],
        [10933, "precneqq"],
        [10934, "scnE"],
        [10934, "succneqq"],
        [10935, "prap"],
        [10935, "precapprox"],
        [10936, "succapprox"],
        [10936, "scap"],
        [10937, "precnapprox"],
        [10937, "prnap"],
        [10938, "scnap"],
        [10938, "succnapprox"],
        [10939, "Pr"],
        [10940, "Sc"],
        [10941, "subdot"],
        [10942, "supdot"],
        [10943, "subplus"],
        [10944, "supplus"],
        [10945, "submult"],
        [10946, "supmult"],
        [10947, "subedot"],
        [10948, "supedot"],
        [10949, "subE"],
        [10949, "subseteqq"],
        [[10949, 824], "nsubseteqq"],
        [[10949, 824], "nsubE"],
        [10950, "supE"],
        [10950, "supseteqq"],
        [[10950, 824], "nsupE"],
        [[10950, 824], "nsupseteqq"],
        [10951, "subsim"],
        [10952, "supsim"],
        [10955, "subsetneqq"],
        [10955, "subnE"],
        [[10955, 65024], "vsubnE"],
        [[10955, 65024], "varsubsetneqq"],
        [10956, "supnE"],
        [10956, "supsetneqq"],
        [[10956, 65024], "vsupnE"],
        [[10956, 65024], "varsupsetneqq"],
        [10959, "csub"],
        [10960, "csup"],
        [10961, "csube"],
        [10962, "csupe"],
        [10963, "subsup"],
        [10964, "supsub"],
        [10965, "subsub"],
        [10966, "supsup"],
        [10967, "suphsub"],
        [10968, "supdsub"],
        [10969, "forkv"],
        [10970, "topfork"],
        [10971, "mlcp"],
        [10980, "Dashv"],
        [10980, "DoubleLeftTee"],
        [10982, "Vdashl"],
        [10983, "Barv"],
        [10984, "vBar"],
        [10985, "vBarv"],
        [10987, "Vbar"],
        [10988, "Not"],
        [10989, "bNot"],
        [10990, "rnmid"],
        [10991, "cirmid"],
        [10992, "midcir"],
        [10993, "topcir"],
        [10994, "nhpar"],
        [10995, "parsim"],
        [11005, "parsl"],
        [[11005, 8421], "nparsl"],
        [64256, "fflig"],
        [64257, "filig"],
        [64258, "fllig"],
        [64259, "ffilig"],
        [64260, "ffllig"],
        [119964, "Ascr"],
        [119966, "Cscr"],
        [119967, "Dscr"],
        [119970, "Gscr"],
        [119973, "Jscr"],
        [119974, "Kscr"],
        [119977, "Nscr"],
        [119978, "Oscr"],
        [119979, "Pscr"],
        [119980, "Qscr"],
        [119982, "Sscr"],
        [119983, "Tscr"],
        [119984, "Uscr"],
        [119985, "Vscr"],
        [119986, "Wscr"],
        [119987, "Xscr"],
        [119988, "Yscr"],
        [119989, "Zscr"],
        [119990, "ascr"],
        [119991, "bscr"],
        [119992, "cscr"],
        [119993, "dscr"],
        [119995, "fscr"],
        [119997, "hscr"],
        [119998, "iscr"],
        [119999, "jscr"],
        [120000, "kscr"],
        [120001, "lscr"],
        [120002, "mscr"],
        [120003, "nscr"],
        [120005, "pscr"],
        [120006, "qscr"],
        [120007, "rscr"],
        [120008, "sscr"],
        [120009, "tscr"],
        [120010, "uscr"],
        [120011, "vscr"],
        [120012, "wscr"],
        [120013, "xscr"],
        [120014, "yscr"],
        [120015, "zscr"],
        [120068, "Afr"],
        [120069, "Bfr"],
        [120071, "Dfr"],
        [120072, "Efr"],
        [120073, "Ffr"],
        [120074, "Gfr"],
        [120077, "Jfr"],
        [120078, "Kfr"],
        [120079, "Lfr"],
        [120080, "Mfr"],
        [120081, "Nfr"],
        [120082, "Ofr"],
        [120083, "Pfr"],
        [120084, "Qfr"],
        [120086, "Sfr"],
        [120087, "Tfr"],
        [120088, "Ufr"],
        [120089, "Vfr"],
        [120090, "Wfr"],
        [120091, "Xfr"],
        [120092, "Yfr"],
        [120094, "afr"],
        [120095, "bfr"],
        [120096, "cfr"],
        [120097, "dfr"],
        [120098, "efr"],
        [120099, "ffr"],
        [120100, "gfr"],
        [120101, "hfr"],
        [120102, "ifr"],
        [120103, "jfr"],
        [120104, "kfr"],
        [120105, "lfr"],
        [120106, "mfr"],
        [120107, "nfr"],
        [120108, "ofr"],
        [120109, "pfr"],
        [120110, "qfr"],
        [120111, "rfr"],
        [120112, "sfr"],
        [120113, "tfr"],
        [120114, "ufr"],
        [120115, "vfr"],
        [120116, "wfr"],
        [120117, "xfr"],
        [120118, "yfr"],
        [120119, "zfr"],
        [120120, "Aopf"],
        [120121, "Bopf"],
        [120123, "Dopf"],
        [120124, "Eopf"],
        [120125, "Fopf"],
        [120126, "Gopf"],
        [120128, "Iopf"],
        [120129, "Jopf"],
        [120130, "Kopf"],
        [120131, "Lopf"],
        [120132, "Mopf"],
        [120134, "Oopf"],
        [120138, "Sopf"],
        [120139, "Topf"],
        [120140, "Uopf"],
        [120141, "Vopf"],
        [120142, "Wopf"],
        [120143, "Xopf"],
        [120144, "Yopf"],
        [120146, "aopf"],
        [120147, "bopf"],
        [120148, "copf"],
        [120149, "dopf"],
        [120150, "eopf"],
        [120151, "fopf"],
        [120152, "gopf"],
        [120153, "hopf"],
        [120154, "iopf"],
        [120155, "jopf"],
        [120156, "kopf"],
        [120157, "lopf"],
        [120158, "mopf"],
        [120159, "nopf"],
        [120160, "oopf"],
        [120161, "popf"],
        [120162, "qopf"],
        [120163, "ropf"],
        [120164, "sopf"],
        [120165, "topf"],
        [120166, "uopf"],
        [120167, "vopf"],
        [120168, "wopf"],
        [120169, "xopf"],
        [120170, "yopf"],
        [120171, "zopf"],
      ]

      EXTEND_ENTITY_TABLE.each do |code_point, data|
        if data.kind_of?(String)
          ENTITY_MAP[code_point] = ENTITY_MAP[data] = Entity.new(code_point, data)
        else
          ENTITY_MAP[code_point] = ENTITY_MAP[data]
        end
      end
    end
  end
end

